@@ -2,13 +2,16 @@
 --                       Barbarians Campaign Mission 1
 -- =======================================================================
 
-set_textdomain("scenario_bar01.wmf")
+push_textdomain("scenario_bar01.wmf")
 
 include "scripting/coroutine.lua"
-include "scripting/objective_utils.lua"
+include "scripting/field_animations.lua"
 include "scripting/infrastructure.lua"
 include "scripting/messages.lua"
-include "scripting/field_animations.lua"
+include "scripting/objective_utils.lua"
+include "scripting/richtext_scenarios.lua"
+include "scripting/table.lua"
+include "scripting/ui.lua"
 
 -- ==========
 -- Constants
