@@ -1,11 +1,14 @@
 -- =======================================================================
 --                         Empire Campaign Mission 2
 -- =======================================================================
-set_textdomain("scenario_emp02.wmf")
+push_textdomain("scenario_emp02.wmf")
 
 include "scripting/coroutine.lua"
+include "scripting/field_animations.lua"
 include "scripting/infrastructure.lua"
+include "scripting/messages.lua"
 include "scripting/objective_utils.lua"
+include "scripting/richtext_scenarios.lua"
 include "scripting/table.lua"
 include "scripting/ui.lua"
 
