@@ -1,7 +1,7 @@
 -- =======================================================================
 --                         Frisian Campaign Mission 1
 -- =======================================================================
-set_textdomain("scenario_fri01.wmf")
+push_textdomain("scenario_fri01.wmf")
 
 include "scripting/coroutine.lua"
 include "scripting/field_animations.lua"
