@@ -153,7 +153,7 @@ function stormflood()
       end
       for idx,fields in ipairs(place_ashes) do
          for idy,f in ipairs(fields) do
-            map:place_immovable("ashes", f, "tribes")
+            map:place_immovable("ashes", f)
          end
       end
       x = next_field.x
@@ -192,6 +192,7 @@ end
 
 function mission_thread()
 
+   p2.hidden_from_general_statistics = true
    --Introduction
    sleep(1000)
    campaign_message_box(intro_1)
@@ -208,6 +209,9 @@ function mission_thread()
       "frisians_foresters_house",
       "frisians_reed_farm"}
    local o = add_campaign_objective(obj_build_wood_economy)
+   -- TODO(Nordfriese): Re-add training wheels code after v1.0
+   -- p1:run_training_wheel("objectives", false)
+
    while not check_for_buildings(p1, {
       frisians_woodcutters_house = 1,
       frisians_foresters_house = 2,
@@ -337,6 +341,7 @@ function mission_thread()
    campaign_message_box(enemies_3)
    scroll_to_field(expansion_mark)
    p1:hide_fields(map.player_slots[2].starting_field:region(6))
+   p2.hidden_from_general_statistics = false
    sleep(1000)
 
    -- Start training
@@ -430,11 +435,11 @@ function mission_thread()
    campaign_message_box(rising_water_5)
 
    -- Wait until an expedition ship is ready
-   local expedition_ready = false
+   local expedition_ready = nil
    while not expedition_ready do
       for idx,ship in ipairs(p1:get_ships()) do
          if (ship.state:sub(1, 4) == "exp_") then
-            expedition_ready = true
+            expedition_ready = ship
             break
          end
       end
@@ -445,15 +450,50 @@ function mission_thread()
    local port = p1:get_buildings("frisians_port")[1]
    scroll_to_field(port.fields[1])
    sleep(1000)
-   local persist = {}
+
+   local persist = {
+      -- Items on the ship. These will be taken unconditionally
+      -- (metals, ores, picks, and miners will be lost on sea though)
+      wares = {},
+      workers = {},
+      ship_soldiers = {},
+      -- Additionally, up to 15/10/5 of the soldiers in the port
+      -- will be taken (depending on scenario difficulty)
+      port_soldiers = {}
+   }
    for descr,n in pairs(port:get_soldiers("all")) do
-      persist[descr[1] .. descr[2] .. descr[3]] = n
+      persist.port_soldiers[descr[1] .. descr[2] .. descr[3]] = n
    end
+   for i,ware in pairs(expedition_ready:get_wares("")) do
+      if persist.wares[ware] then
+         persist.wares[ware] = persist.wares[ware] + 1
+      else
+         persist.wares[ware] = 1
+      end
+   end
+   for i,worker in pairs(expedition_ready:get_workers("")) do
+      local n = worker.descr.name
+      if n == "frisians_soldier" then
+         n = worker.health_level .. worker.attack_level .. worker.defense_level
+         if persist.ship_soldiers[n] then
+            persist.ship_soldiers[n] = persist.ship_soldiers[n] + 1
+         else
+            persist.ship_soldiers[n] = 1
+         end
+      elseif persist.workers[n] then
+         persist.workers[n] = persist.workers[n] + 1
+      else
+         persist.workers[n] = 1
+      end
+   end
+
    -- We save a table of all soldiers we can take with us:
    -- {
-   --    "262" = 5,
-   --    "120" = 2,
-   --    ...
+   --    port_soldiers = {
+   --       "262" = 5,
+   --       "120" = 2,
+   --       ...
+   --    }
    -- }
    -- means 5 soldiers with training levels health-2/attack-6/defense-2 and
    -- 2 soldiers with health-1/attack-2/defense-0.
