@@ -2,8 +2,6 @@
 -- Some formating functions
 -- =========================
 
-include "scripting/richtext_scenarios.lua"
-
 function reebaud(title, text)
    return speech("map:reebaud.png", "55BB55", title, text)
 end
@@ -71,7 +69,7 @@ obj_supply_murilius = {
       li(_"30 × Coal") ..
       li(_"40 × Iron Ore") ..
       li(_"20 × Iron") ..
-      li(_"30 × Gold Ore") ..
+      li(_"20 × Gold Ore") ..
       li(_"10 × Gold") ..
       -- TRANSLATORS: Continues from "Decide whether you want to work with Murilius against the Barbarians. If so, fill his warehouse with these wares: [list of wares]"
       p(_([[Otherwise, just destroy the warehouse and risk having Murilius as an enemy. He forbade you to expand your territory until the wares have been handed over.]]))
@@ -126,22 +124,23 @@ obj_defeat_both = {
 -- Texts to the user
 -- ==================
 
-campaign_data_warning = {
-   title = _"Warning",
-   body = p(_[[You appear not to have completed the previous mission. You may still play this scenario, but you will be at a disadvantage. I recommend that you complete the previous scenario first and then restart this mission.]]),
-   w = 450,
-   h = 150,
-}
+-- TRANSLATORS: Reebaud – Introduction 1
+local intro_1_start = _([[I began to believe the journey would never end. I have no idea how long we were at sea, tossed about by envious storms… it must have been months.]])
+-- TRANSLATORS: Reebaud – Introduction 1
+local intro_1_iron = _([[The storms maintained a firm grip on the ship throughout our voyage. There was hardly a day on which we did not wonder whether it would be our last. We were compelled to drop the precious metals we had taken with us overboard to steady the ship, feeling as though it were a squalid sacrifice to the gods to give us hope to live a few hours longer.]])
+-- TRANSLATORS: Reebaud – Introduction 1
+local intro_1_picks = _([[The few tools we managed to salvage from Langeness did not cope well. The miners’ picks proved especially vulnerable, and we had to throw them in the ocean when it became evident that they had been corroded by the sea salt so much that we could never again mine anything with them.]])
+-- TRANSLATORS: Reebaud – Introduction 1
+local intro_1_end = _([[But we survived. Finally, we reached the mouth of a calmer fjord. We sailed upriver, and arrived here.]])
 
+local intro_1_body = ""
+if lost_metals then intro_1_body = intro_1_iron .. paragraphdivider() end
+if lost_miners then intro_1_body = intro_1_body .. intro_1_picks .. paragraphdivider() end
 intro_1 = {
    title =_ "Welcome Back!",
-   body=reebaud(_"A new home",
-      -- TRANSLATORS: Reebaud – Introduction 1
-      _([[I began to believe the journey would never end. I have no idea how long we were on the sea, tossed about by envious storms… it must have been months.]])
-      .. paragraphdivider() ..
-      -- TRANSLATORS: Reebaud – Introduction 1
-      _([[But we survived. Finally, we reached the mouth of a calmer fjord. We sailed upriver, and arrived here.]])),
+   body=reebaud(_"A new home", intro_1_start .. paragraphdivider() .. intro_1_body .. intro_1_end),
 }
+
 intro_2 = {
    title =_ "Welcome Back!",
    body=reebaud(_"A new home",
@@ -243,7 +242,7 @@ aqua_farm_4 = {
    title =_ "Recruiting",
    body=reebaud(_"Our economy is complete",
       -- TRANSLATORS: Reebaud – Aqua Farms 4
-      _([[You are right – we should build more berry farms, collector’s houses and taverns as well as a drinking hall, and advanced bakeries and breweries.]])
+      _([[You are right – we should build more berry farms, fruit collector’s houses and taverns as well as a drinking hall, and advanced bakeries and breweries.]])
       .. paragraphdivider() ..
       -- TRANSLATORS: Reebaud – Aqua Farms 4
       _([[However, we can already start focusing on recruiting and training soldiers. We can now afford to use metal for weapons, helmets and garments. I propose building armor smithies, a barracks, a training arena and a tailor’s shop now.]])),
@@ -274,8 +273,8 @@ supply_murilius_3 = {
 supply_murilius_4 = {
    title =_ "We Are Not Alone",
    body=reebaud(_"Strangers",
-      -- TRANSLATORS: Reebaud – Supply Murilius 4
-      _([[Greetings, representative of the Empire! I am Reebaud, the chieftain of this tribe. All we want is to settle down here, build our home and live our lives in peace. We do not seek trouble, but we aren’t afraid to fight, either.]])),
+      -- TRANSLATORS: Reebaud – Supply Murilius 4. "Peace" is the traditional frisian greeting, nothing more.
+      _([[Peace, representative of the Empire! I am Reebaud, the chieftain of this tribe. All we want is to settle down here, build our home and live our lives in peace. We do not seek trouble, but we aren’t afraid to fight, either.]])),
 }
 supply_murilius_5 = {
    title =_ "We Are Not Alone",
@@ -414,5 +413,5 @@ victory_1 = {
       -- TRANSLATORS: Reebaud – victory
       _([[We have defeated all our enemies! Now no other tribe will ever dare settle here again. We are safe, and we can finally live our lives in peace.]]))
       .. objective_text(_"Congratulations",
-      [[You have completed this mission. You may continue playing if you wish, otherwise move on to the next mission.]]),
+      _[[You have completed this mission. You may continue playing if you wish, otherwise move on to the next mission.]]),
 }
