@@ -5,12 +5,15 @@
 plr = wl.Game().players[1]
 map = wl.Game().map
 
+push_textdomain("scenario_tutorial01_basic_control.wmf")
+
 include "scripting/coroutine.lua"
+include "scripting/field_animations.lua"
 include "scripting/infrastructure.lua"
 include "scripting/messages.lua"
+include "scripting/richtext_scenarios.lua"
 include "scripting/table.lua"
 include "scripting/ui.lua"
-include "scripting/field_animations.lua"
 
 -- Constants
 sf = map.player_slots[1].starting_field
@@ -26,9 +29,6 @@ immovable_is_legal = function(i) return false end
 
 include "map:scripting/starting_conditions.lua"
 
--- Starting conditions switch the textdomain
-set_textdomain("scenario_tutorial01_basic_control.wmf")
-
 include "map:scripting/texts.lua"
 include "map:scripting/helper_functions.lua"
 include "map:scripting/helper_functions_demonstration.lua"
