@@ -75,7 +75,7 @@ obj_battlearena = {
    number = 1,
    body = objective_text(_"Build a battle arena",
       li(_[[Build a battle arena. It is a big building.]]) ..
-      li_arrow(_[[Since the construction will take some time, you can change the game speed using Page Up and Page Down.]])
+      li_arrow(_([[Since the construction will take some time, you can change the game speed using %1$s and %2$s.]]):bformat(wl.ui.get_shortcut("game_speed_up"), wl.ui.get_shortcut("game_speed_down")))
    )
 }
 
@@ -122,7 +122,7 @@ trainingcamp2 = {
       p(_[[Great, our training camp has now been finished, too. Now nothing will hinder us from getting the strongest warriors the world has ever seen.]]) ..
       p(_[[To train in the training camp, our soldiers need food like in the battle arena, but no strong beer. Instead, they need different axes for attack training and helmets for health training.]]) ..
       p(_[[This equipment is produced in smithies out of coal, iron, and sometimes gold. You will learn more about this in the second scenario of the Barbarian campaign.]]) ..
-      p(_[[You should also keep in mind that each of the three tribes in Widelands has its own way of training, so the buildings and wares are different. Also, the ability levels cannot be compared: an Imperial soldier has a base attack of %1% at level 0, while a Barbarian soldier at the same level only has a base attack of %2%.]]:bformat(empire_soldier.base_min_attack, soldier.base_min_attack))
+      p(_[[You should also keep in mind that each of the tribes in Widelands has its own way of training, so the buildings and wares are different. Also, the ability levels cannot be compared: an Imperial soldier has a base attack of %1% at level 0, while a Barbarian soldier at the same level only has a base attack of %2%.]]:bformat(empire_soldier.base_min_attack, soldier.base_min_attack))
    )
 }
 
@@ -153,7 +153,7 @@ scouting2 = {
    title = _"Scout is ready",
    body = (
       h1(_"Ready to go!") ..
-      p(_[[Well done, your scout’s hut has been built. While our scout is moving in, let’s learn a little bit more about him.]]) ..
+      p(_[[Well done! Your scout’s hut has been built. While our scout is moving in, let’s learn a little bit more about him.]]) ..
       p(_[[First of all, he will need to take some food with him on his scouting trips. Fortunately, we have some rations in our warehouse.]]) ..
       li_object("barbarians_scout", _[[When provided with food, he will walk randomly around the area. You should follow his movement before fog of war hides what he saw.]], plr.color)
    )
