@@ -4,32 +4,44 @@
 --
 -- This script contains function that ease setting up an initial infrastructure
 -- for maps. This includes placing buildings and roads.
+--
+-- To make these functions available include this file at the beginning
+-- of a script via:
+--
+-- .. code-block:: lua
+--
+--    include "scripting/infrastructure.lua"
+--
 
 -- RST
 -- .. function:: connected_road(roadtype, plr, sflag, descr[, create_carriers = true])
 --
 --    This is a convenience function to create roads and waterways. It is basically a frontend
---    to :meth:`wl.game.Player.place_road`. The road is forced, that is other
+--    to :meth:`wl.bases.PlayerBase.place_road`. The road is forced, that is other
 --    stuff in the way is removed. A sample usage:
 --
 --    .. code-block:: lua
 --
 --       local game = wl.Game()
---       connected_road("normal", game.players[1], game.map:get_field(20,20).immovable, "r,r|br,r|r,r")
+--       field = game.map:get_field(20, 20)
+--       building = game.players[1]:place_building("barbarians_sentry", field, true, true)
+--       connected_road("normal", game.players[1], building.flag, "r,r|br,r|r,r")
 --
---    This would create a road starting from the Flag standing at field(20,20)
---    which must exist and goes from there 2 steps right (east), places a new
+--    After placing a building this would create a road starting from the
+--    building’s flag and goes from there 2 steps right (east), places a new
 --    flag. Then it goes one step bottom-right and one step right, places the
 --    next flag and then goes two steps right again and places the last flag.
+--    If a flag at this last position already exists, the road gets connected
+--    to the existing flag.
 --
---    :arg roadtype: 'normal', 'busy', or 'waterway'
+--    :arg roadtype: :const:`"normal"`, :const:`"busy"`, or :const:`"waterway"`
 --    :type roadtype: :class:`string`
 --    :arg plr: The player for which the road is created
 --    :type plr: :class:`wl.game.Player`
 --    :arg sflag: The starting flag for this road.
 --    :type sflag: :class:`wl.map.Flag`
 --    :arg descr: The description of this road. This are comma separated
---       directions as those accepted by :meth:`wl.game.Player.place_road`. A
+--       directions as those accepted by :meth:`wl.bases.PlayerBase.place_road`. A
 --       :const:`|` defines a flag.
 --    :arg create_carriers: If this is :const:`true` carriers are created for
 --       the roads. Otherwise no carriers will be created.
@@ -65,44 +77,45 @@ end
 -- RST
 -- .. function:: prefilled_buildings(plr, b1_descr[, b2_descr, ...])
 --
---    Create pre-filled buildings. Each description is a arrays which contain
---    building type, build field and pre-fill information. A sample usage:
+--    Create pre-filled buildings. Each description is an array which contains
+--    building type, x and y coordinates and pre-fill information.
+--    A sample usage:
 --
 --    .. code-block:: lua
 --
 --       prefilled_buildings(wl.Game().players[1],
---          {"sentry", 57, 9}, -- Sentry completely full with soldiers
---          {"sentry", 57, 9, soldier={[{0,0,0,0}]=1}}, -- Sentry with one soldier
---          {"bakery", 55, 20, inputs = {wheat=6, water=6}}, -- bakery with wares and workers
---          {"well", 52, 30}, -- a well with workers
+--          {"empire_sentry", 57, 9},                               -- Sentry completely full with soldiers
+--          {"empire_sentry", 57, 9, soldiers={[{0,0,0,0}]=1}},     -- Sentry with one soldier
+--          {"empire_bakery", 55, 20, inputs = {wheat=6, water=6}}, -- bakery with wares and workers
+--          {"empire_well", 52, 30},                                -- a well with workers
 --       )
 --
 --    :arg plr: The player for which the building is created
 --    :type plr: :class:`wl.game.Player`
---    :arg b1_descr: An array of tables. Each table must contain at
---       least the name of the building, and the x and y positions of the field
+--    :arg b1_descr: An :const:`array` of tables. Each table must contain at
+--       least the name of the building, and the x and y position of the field
 --       where the building should be created. Optional entries are:
 --
 --       wares
---          A table of (name,count) as expected by
---          :meth:`wl.map.Warehouse.set_wares`. This is valid for
+--          A table of {:const:`"ware_name"`,count} as expected by
+--          :meth:`wl.map.HasWares.set_wares`. This is valid for
 --          :class:`wl.map.Warehouse` and must not be used otherwise.
 --       inputs
---          A table of (name,count) as expected by
---          :meth:`wl.map.ProductionSite.set_inputs`. Inputs are wares or workers
+--          A table of {:const:`"name"`,count} as expected by
+--          :meth:`wl.map.HasInputs.set_inputs`. Inputs are wares or workers
 --          which are consumed by the building. This is valid for
 --          :class:`wl.map.ProductionSite` and must not be used otherwise.
 --       soldiers
---          A table of (soldier_descr,count) as expected by
+--          A table of {{soldier_descr},count} as expected by
 --          :meth:`wl.map.HasSoldiers.set_soldiers`.  If this is nil, the site
 --          will be filled with {0,0,0,0} soldiers.
 --       workers
---          A table of (workers_name,count) as expected by
---          :meth:`wl.map.Warehouse.set_workers`.  Note that ProductionSites
+--          A table of {:const:`"worker_name"`,count} as expected by
+--          :meth:`wl.map.HasWorkers.set_workers`.  Note that ProductionSites
 --          are filled with workers by default.
 --    :type b1_descr: :class:`array`
 --
---    :returns: A table of created buildings
+--    :returns: A table of created :class:`buildings <wl.map.Building>`
 
 function prefilled_buildings(p, ...)
    local b_table = {}
@@ -143,15 +156,16 @@ end
 --    :arg building: The name of the building to create.
 --    :type building: :class:`string`
 --    :arg region: The fields which are tested for suitability.
+--                 See: :meth:`wl.map.Field.region`
 --    :type region: :class:`array`
 --    :arg opts:  A table with prefill information (wares, soldiers, workers,
---       see :func:`prefilled_buildings`)
+--                see :func:`prefilled_buildings`)
 --    :type opts: :class:`table`
 --
---    :returns: The building created
+--    :returns: The :class:`wl.map.Building` created
 
 function place_building_in_region(plr, building, fields, gargs)
-   set_textdomain("widelands")
+   push_textdomain("widelands")
    local idx
    local f
    local args = gargs or {}
@@ -168,12 +182,13 @@ function place_building_in_region(plr, building, fields, gargs)
       end
       table.remove(fields, idx)
    end
-   plr:send_message(
+   plr:send_to_inbox(
       -- TRANSLATORS: Short for "Not enough space"
       _"No Space",
       p(_([[Some of your starting buildings didn’t have enough room and weren’t built. You are at a disadvantage with this; consider restarting this map with a fair starting condition.]])),
       {popup=true, heading=_"Not enough space"}
    )
+   pop_textdomain()
 end
 
 
@@ -185,7 +200,17 @@ end
 --
 --    :arg immovable: The immovable to test
 --
---    :returns: true if the immovable is a building
+--    :returns: :const:`true` if the immovable is a building
+--
+--    Example:
+--
+--    .. code-block:: lua
+--
+--       field = wl.Game().map:get_field(20, 45)
+--       if field.immovable then
+--          if is_building(field.immovable) then
+--             -- do something ..
+--
 
 function is_building(immovable)
    return immovable.descr.type_name == "productionsite" or
@@ -200,8 +225,11 @@ end
 --    Adds(subtracts) wares to the first warehouse of specified type
 --
 --    :arg player: the player to add wares to
---    :arg warehouse: The type of warehouse (string) to add wares to
---    :arg waretable: a table of pairs {ware = value}
+--    :type player: :class:`wl.game.Player`
+--    :arg warehouse: The type of warehouse to add wares to, e.g. :const:`"empire_warehouse"`
+--    :type warehouse: :const:`"string"`
+--    :arg waretable: a table of pairs {:const:`"warename"` = value}
+--    :type waretable: :class:`table`
 
 function add_wares_to_warehouse(player, warehouse, waretable)
    local hq = player:get_buildings(warehouse)[1]
@@ -217,13 +245,20 @@ end
 -- RST
 -- .. function:: check_trees_rocks_poor_hamlet(player, sf, warehouse, waretable_rocks, waretable_trees)
 --
---    Checks for rocks or trees in the region of the player starting field and adds wares if no immovables found
+--    Used for starting condition "Poor Hamlet". Checks for rocks or trees in
+--    the region of the player starting field and adds wares to the warehouse
+--    if no immovables were found.
 --
 --    :arg player: the player to check
+--    :type player: :class:`wl.game.Player`
 --    :arg sf: starting field of the player
---    :arg warehouse: The type of warehouse (string) to add wares to
---    :arg waretable_rocks: a table of pairs {ware = value} to add if no rocks
---    :arg waretable_trees: a table of pairs {ware = value} to add if no trees
+--    :type sf: :attr:`starting_field`
+--    :arg warehouse: The type of warehouse to add wares to
+--    :type warehouse: :const:`string`
+--    :arg waretable_rocks: a table of pairs {:const:`"name"` = value} to add if no rocks were found nearby
+--    :type waretable_rocks: :const:`table`
+--    :arg waretable_trees: a table of pairs {:const:`"name"` = value} to add if no trees were found nearby
+--    :type waretable_trees: :const:`table`
 
 function check_trees_rocks_poor_hamlet(player, sf, warehouse, waretable_rocks, waretable_trees)
    -- NOTE: pessimistically, this could be a single rock and a single tree
@@ -243,11 +278,11 @@ function check_trees_rocks_poor_hamlet(player, sf, warehouse, waretable_rocks, w
    end
    if not has_rocks then
       add_wares_to_warehouse(player, warehouse, waretable_rocks)
-      player:send_message(_"No rocks nearby", _"There are no rocks near to your starting position. Therefore, you receive extra resources for bootstrapping your economy.")
+      player:send_to_inbox(_"No rocks nearby", _"There are no rocks near to your starting position. Therefore, you receive extra resources for bootstrapping your economy.")
    end
    -- adding exactly one forester
    if not has_trees then
       add_wares_to_warehouse(player, warehouse, waretable_trees)
-      player:send_message(_"No trees nearby", _"There are no trees near to your starting position. Therefore, you receive extra resources for bootstrapping your economy.")
+      player:send_to_inbox(_"No trees nearby", _"There are no trees near to your starting position. Therefore, you receive extra resources for bootstrapping your economy.")
    end
 end
