@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_militarysite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_militarysite_type {
    name = "barbarians_barrier",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Barrier"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
 
@@ -38,14 +38,21 @@ tribes:new_militarysite_type {
 
    max_soldiers = 5,
    heal_per_second = 130,
-   conquers = 8,
+   conquers = 9,
    prefer_heroes = true,
 
    messages = {
-      occupied = _"Your soldiers have occupied your barrier.",
-      aggressor = _"Your barrier discovered an aggressor.",
-      attack = _"Your barrier is under attack.",
-      defeated_enemy = _"The enemy defeated your soldiers at the barrier.",
-      defeated_you = _"Your soldiers defeated the enemy at the barrier."
+      -- TRANSLATORS: Message sent by a Barbarian military site
+      occupied = pgettext("barbarians_building", "Your soldiers have occupied your barrier."),
+      -- TRANSLATORS: Message sent by a Barbarian military site
+      aggressor = pgettext("barbarians_building", "Your barrier discovered an aggressor."),
+      -- TRANSLATORS: Message sent by a Barbarian military site
+      attack = pgettext("barbarians_building", "Your barrier is under attack."),
+      -- TRANSLATORS: Message sent by a Barbarian military site
+      defeated_enemy = pgettext("barbarians_building", "The enemy defeated your soldiers at the barrier."),
+      -- TRANSLATORS: Message sent by a Barbarian military site
+      defeated_you = pgettext("barbarians_building", "Your soldiers defeated the enemy at the barrier.")
    },
 }
+
+pop_textdomain()
