@@ -10,12 +10,9 @@
 --
 -- The dismantlesite is defined in
 -- ``buildings/partially_finished/dismantlesite/init.lua``.
--- The building will also need its help texts, which are defined in
--- ``buildings/partially_finished/dismantlesite/helptexts.lua``
-
-dirname = path.dirname(__file__)
-
--- RST
+-- The building will also need its :ref:`help texts <lua_tribes_tribes_helptexts>`,
+-- which are defined in ``data/tribes/initialization/<tribe_name>/units.lua``
+--
 -- .. function:: new_dismantlesite_type{table}
 --
 --    This function adds the definition of the dismantle site building to the engine.
@@ -23,12 +20,42 @@ dirname = path.dirname(__file__)
 --    :arg table: This table contains all the data that the game engine will add to this building.
 --                It only contains :ref:`lua_tribes_buildings_common`.
 --
-tribes:new_dismantlesite_type {
-   msgctxt = "building",
+-- For making the UI texts translateable, we also need to push/pop the correct textdomain.
+--
+-- Example:
+--
+-- .. code-block:: lua
+--
+--    push_textdomain("tribes")
+--
+--    dirname = path.dirname(__file__)
+--
+--    descriptions:new_dismantlesite_type {
+--       name = "dismantlesite",
+--       descname = pgettext("building", "Dismantle Site"),
+--       animation_directory = dirname,
+--       icon = dirname .. "menu.png",
+--       vision_range = 2,
+--
+--       animations = {
+--          idle = {
+--             hotspot = { 5, 5 },
+--          },
+--       },
+--
+--       aihints = {},
+--    }
+--
+--    pop_textdomain()
+
+push_textdomain("tribes")
+
+dirname = path.dirname(__file__)
+
+descriptions:new_dismantlesite_type {
    name = "dismantlesite",
    -- TRANSLATORS: This is a name used in lists of buildings for buildings being taken apart
    descname = pgettext("building", "Dismantle Site"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    vision_range = 2,
 
@@ -41,3 +68,5 @@ tribes:new_dismantlesite_type {
 
    aihints = {},
 }
+
+pop_textdomain()
