@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "atlanteans_building",
+descriptions:new_productionsite_type {
    name = "atlanteans_blackroot_farm",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Blackroot Farm"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "big",
 
@@ -38,18 +38,8 @@ tribes:new_productionsite_type {
       atlanteans_blackroot_farmer = 1
    },
 
-   outputs = {
-      "blackroot"
-   },
-
-   indicate_workarea_overlaps = {
-      atlanteans_blackroot_farm = false,
-      atlanteans_farm = false,
-      atlanteans_foresters_house = false,
-   },
-
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
          descname = _"working",
          actions = {
@@ -62,7 +52,7 @@ tribes:new_productionsite_type {
          descname = _"planting blackroot",
          actions = {
             "callworker=plant",
-            "sleep=10000"
+            "sleep=duration:10s"
          }
       },
       harvest = {
@@ -70,7 +60,7 @@ tribes:new_productionsite_type {
          descname = _"harvesting blackroot",
          actions = {
             "callworker=harvest",
-            "sleep=3000"
+            "sleep=duration:3s"
          }
       },
    },
@@ -82,3 +72,5 @@ tribes:new_productionsite_type {
       productivity_threshold = 30
    },
 }
+
+pop_textdomain()
