@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "atlanteans_building",
+descriptions:new_productionsite_type {
    name = "atlanteans_fishers_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Fisher’s House"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -26,24 +26,23 @@ tribes:new_productionsite_type {
 
    aihints = {
       needs_water = true,
-      prohibited_till = 600
+      basic_amount = 1,
+      prohibited_till = 540,
+      very_weak_ai_limit = 2,
+      weak_ai_limit = 4
    },
 
    working_positions = {
       atlanteans_fisher = 1
    },
 
-   outputs = {
-      "fish"
-   },
-
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start fishing because ...
          descname = _"fishing",
          actions = {
-            "sleep=16000",
-            "worker=fish"
+            "callworker=fish",
+            "sleep=duration:9s500ms"
          }
       },
 
@@ -55,3 +54,5 @@ tribes:new_productionsite_type {
       message = pgettext("atlanteans_building", "The fisher working out of this fisher’s house can’t find any fish in his work area. Remember that you can increase the number of existing fish by building a fish breeder’s house."),
    },
 }
+
+pop_textdomain()
