@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "atlanteans_building",
+descriptions:new_productionsite_type {
    name = "atlanteans_foresters_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Forester’s House"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -28,8 +28,8 @@ tribes:new_productionsite_type {
 
    aihints = {
       space_consumer = true,
-      renews_map_resource = "log",
-      prohibited_till = 240
+      very_weak_ai_limit = 2,
+      weak_ai_limit = 4
    },
 
    working_positions = {
@@ -37,13 +37,15 @@ tribes:new_productionsite_type {
    },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start planting trees because ...
          descname = _"planting trees",
          actions = {
-            "sleep=11000",
-            "worker=plant"
+            "callworker=plant",
+            "sleep=duration:8s"
          }
       },
    },
 }
+
+pop_textdomain()
