@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "atlanteans_building",
+descriptions:new_productionsite_type {
    name = "atlanteans_hunters_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Hunter’s House"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -26,24 +26,20 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      prohibited_till = 400
+      prohibited_till = 380
    },
 
    working_positions = {
       atlanteans_hunter = 1
    },
 
-   outputs = {
-      "meat"
-   },
-
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start hunting because ...
          descname = _"hunting",
          actions = {
-            "sleep=35000",
-            "worker=hunt"
+            "callworker=hunt",
+            "sleep=duration:35s"
          }
       },
    },
@@ -57,3 +53,5 @@ tribes:new_productionsite_type {
       productivity_threshold = 0
    },
 }
+
+pop_textdomain()
