@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_barracks",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Barracks"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
 
@@ -13,7 +13,7 @@ tribes:new_productionsite_type {
       log = 4,
       granite = 2,
       grout = 4,
-      thatch_reed = 1
+      reed = 1
    },
    return_on_dismantle = {
       log = 2,
@@ -21,23 +21,19 @@ tribes:new_productionsite_type {
       grout = 1
    },
 
-   animations = {
-      idle = { -- TODO(GunChleoc): make animations
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 50, 38 },
-      },
-      build = { -- TODO(GunChleoc): make animations
-         pictures = path.list_files(dirname .. "build_??.png"),
-         hotspot = { 50, 38 },
-      },
-      working = { -- TODO(GunChleoc): make animations
-         pictures = path.list_files(dirname .. "working_??.png"),
-         hotspot = { 50, 38 },
+   animation_directory = dirname,
+   -- TODO(Nordfriese): Make animations.
+   animations = {idle = {hotspot = {57, 49}}},
+   spritesheets = {
+      build = {
+         hotspot = {57, 49},
+         frames = 3,
+         columns = 1,
+         rows = 3
       }
    },
 
    aihints = {
-      basic_amount = 1,
       very_weak_ai_limit = 1,
       weak_ai_limit = 2,
       prohibited_till = 920
@@ -51,21 +47,19 @@ tribes:new_productionsite_type {
       { name = "ax", amount = 8 },
       { name = "barbarians_recruit", amount = 8 }
    },
-   outputs = {
-      "barbarians_soldier",
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start recruiting soldier because ...
          descname = pgettext("barbarians_building", "recruiting soldier"),
          actions = {
-            "sleep=15000",
             "return=skipped unless economy needs barbarians_soldier",
             "consume=ax barbarians_recruit",
-            "animate=working 15000",
+            "sleep=duration:30s",
             "recruit=barbarians_soldier"
          }
       },
    }
 }
+
+pop_textdomain()
