@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_cattlefarm",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Cattle Farm"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "big",
 
@@ -42,22 +42,21 @@ tribes:new_productionsite_type {
       { name = "water", amount = 8 },
       { name = "wheat", amount = 8 }
    },
-   outputs = {
-      "barbarians_ox"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start rearing cattle because ...
          descname = pgettext("barbarians_building", "rearing cattle"),
          actions = {
             "return=skipped unless economy needs barbarians_ox",
             "consume=wheat water",
-            "sleep=15000",
-            "playsound=sound/farm/ox 192",
-            "animate=working 15000", -- Animation of feeding the cattle
+            "sleep=duration:15s",
+            "playsound=sound/farm/ox priority:50% allow_multiple",
+            "animate=working duration:15s", -- Animation of feeding the cattle
             "recruit=barbarians_ox"
          }
       },
    },
 }
+
+pop_textdomain()
