@@ -1,18 +1,18 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_charcoal_kiln",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Charcoal Kiln"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
 
    buildcost = {
       log = 3,
       grout = 2,
-      thatch_reed = 2
+      reed = 2
    },
    return_on_dismantle = {
       log = 2,
@@ -35,7 +35,7 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      prohibited_till = 690
+      basic_amount = 1
    },
 
    working_positions = {
@@ -45,21 +45,20 @@ tribes:new_productionsite_type {
    inputs = {
       { name = "log", amount = 8 }
    },
-   outputs = {
-      "coal"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start producing coal because ...
          descname = _"producing coal",
          actions = {
-            "sleep=30000",
             "return=skipped unless economy needs coal",
             "consume=log:6",
-            "animate=working 90000", -- Charcoal fires will burn for some days in real life
+            "sleep=duration:30s",
+            "animate=working duration:1m30s", -- Charcoal fires will burn for some days in real life
             "produce=coal"
          }
       },
    },
 }
+
+pop_textdomain()
