@@ -1,14 +1,25 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_coalmine",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Coal Mine"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "mine",
-   enhancement = "barbarians_coalmine_deep",
+
+   enhancement = {
+      name = "barbarians_coalmine_deep",
+      enhancement_cost = {
+         log = 4,
+         granite = 2
+      },
+      enhancement_return_on_dismantle = {
+         log = 2,
+         granite = 1
+      }
+   },
 
    buildcost = {
       log = 4,
@@ -39,8 +50,6 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      mines = "coal",
-      mines_percent = 30,
       prohibited_till = 910
    },
 
@@ -51,29 +60,25 @@ tribes:new_productionsite_type {
    inputs = {
       { name = "ration", amount = 6 }
    },
-   outputs = {
-      "coal"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start mining coal because ...
          descname = _"mining coal",
          actions = {
-            "sleep=5000",
             "return=skipped unless economy needs coal",
             "consume=ration",
-            "sleep=40000",
+            "sleep=duration:45s",
             "call=mine_produce",
             "call=mine_produce",
-            "return=no_stats"
+            "return=skipped"
          }
       },
       mine_produce = {
          descname = _"mining coal",
          actions = {
-            "animate=working 10000",
-            "mine=coal 2 33 5 17",
+            "animate=working duration:10s",
+            "mine=resource_coal radius:2 yield:33.33% when_empty:5% experience_on_fail:17%",
             "produce=coal",
          }
       },
@@ -94,3 +99,5 @@ tribes:new_productionsite_type {
          pgettext("barbarians_building", "This coal mine’s main vein is exhausted. Expect strongly diminished returns on investment. You should consider enhancing, dismantling or destroying it."),
    },
 }
+
+pop_textdomain()
