@@ -1,14 +1,13 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_ironmine",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Iron Mine"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "mine",
-   enhancement = "barbarians_ironmine_deep",
 
    buildcost = {
       log = 4,
@@ -19,6 +18,18 @@ tribes:new_productionsite_type {
       granite = 1
    },
 
+   enhancement = {
+      name = "barbarians_ironmine_deep",
+      enhancement_cost = {
+         log = 4,
+         granite = 2
+      },
+      enhancement_return_on_dismantle = {
+         log = 2,
+         granite = 1
+      }
+   },
+
    animations = {
       idle = {
          pictures = path.list_files(dirname .. "idle_??.png"),
@@ -39,9 +50,7 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      mines = "iron",
-      prohibited_till = 1000,
-      mines_percent = 30
+      prohibited_till = 1000
    },
 
    working_positions = {
@@ -51,26 +60,17 @@ tribes:new_productionsite_type {
    inputs = {
       { name = "ration", amount = 6 }
    },
-   outputs = {
-      "iron_ore"
-   },
-
-   indicate_workarea_overlaps = {
-      barbarians_ironmine = false,
-      barbarians_ironmine_deep = false,
-      barbarians_ironmine_deeper = false,
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start mining iron because ...
          descname = _"mining iron",
          actions = {
             "return=skipped unless economy needs iron_ore",
             "consume=ration",
-            "sleep=45000",
-            "animate=working 20000",
-            "mine=iron 2 33 5 17",
+            "sleep=duration:45s",
+            "animate=working duration:20s",
+            "mine=resource_iron radius:2 yield:33.33% when_empty:5% experience_on_fail:17%",
             "produce=iron_ore"
          }
       },
@@ -83,3 +83,5 @@ tribes:new_productionsite_type {
          pgettext("barbarians_building", "This iron mine’s main vein is exhausted. Expect strongly diminished returns on investment. You should consider enhancing, dismantling or destroying it."),
    },
 }
+
+pop_textdomain()
