@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_rangers_hut",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Ranger’s Hut"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -32,9 +32,10 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      renews_map_resource = "log",
       space_consumer = true,
-      prohibited_till = 200
+      basic_amount = 1,
+      very_weak_ai_limit = 3,
+      weak_ai_limit = 5
    },
 
    working_positions = {
@@ -42,13 +43,15 @@ tribes:new_productionsite_type {
    },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start planting trees because ...
          descname = _"planting trees",
          actions = {
-            "sleep=16000",
-            "worker=plant"
+            "callworker=plant",
+            "sleep=duration:11s500ms"
          }
       },
    },
 }
+
+pop_textdomain()
