@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_scouts_hut",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Scout’s Hut"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -44,14 +44,23 @@ tribes:new_productionsite_type {
    },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start scouting because ...
          descname = _"scouting",
          actions = {
-            "sleep=30000",
             "consume=ration",
-            "worker=scout"
+            "sleep=duration:30s",
+            "callworker=scout"
+         }
+      },
+      targeted_scouting = {
+         descname = _"scouting",
+         actions = {
+            "consume=ration",
+            "callworker=targeted_scouting"
          }
       },
    },
 }
+
+pop_textdomain()
