@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_smelting_works",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Smelting Works"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
 
@@ -49,13 +49,9 @@ tribes:new_productionsite_type {
       { name = "iron_ore", amount = 8 },
       { name = "gold_ore", amount = 8 }
    },
-   outputs = {
-      "iron",
-      "gold"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
          descname = _"working",
          actions = {
@@ -71,10 +67,10 @@ tribes:new_productionsite_type {
          actions = {
             "return=skipped unless economy needs iron",
             "consume=coal iron_ore",
-            "sleep=29000",
-            "playsound=sound/metal/furnace 192",
-            "animate=working 35000",
-            "playsound=sound/metal/ironping 80",
+            "sleep=duration:29s",
+            "playsound=sound/metal/furnace priority:50% allow_multiple",
+            "animate=working duration:35s",
+            "playsound=sound/metal/ironping priority:60%",
             "produce=iron"
          }
       },
@@ -84,10 +80,10 @@ tribes:new_productionsite_type {
          actions = {
             "return=skipped unless economy needs iron",
             "consume=coal iron_ore",
-            "sleep=29000",
-            "playsound=sound/metal/furnace 192",
-            "animate=working 35000",
-            "playsound=sound/metal/ironping 80",
+            "sleep=duration:29s",
+            "playsound=sound/metal/furnace priority:50% allow_multiple",
+            "animate=working duration:35s",
+            "playsound=sound/metal/ironping priority:60%",
             "produce=iron"
          }
       },
@@ -97,12 +93,14 @@ tribes:new_productionsite_type {
          actions = {
             "return=skipped unless economy needs gold",
             "consume=coal gold_ore",
-            "sleep=29000",
-            "playsound=sound/metal/furnace 192",
-            "animate=working 35000",
-            "playsound=sound/metal/goldping 80",
+            "sleep=duration:29s",
+            "playsound=sound/metal/furnace priority:50% allow_multiple",
+            "animate=working duration:35s",
+            "playsound=sound/metal/goldping priority:60%",
             "produce=gold"
          }
       },
    },
 }
+
+pop_textdomain()
