@@ -1,20 +1,32 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_tavern",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Tavern"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
-   enhancement = "barbarians_inn",
+
+   enhancement = {
+      name = "barbarians_inn",
+      enhancement_cost = {
+         log = 2,
+         grout = 2,
+         reed = 1
+      },
+      enhancement_return_on_dismantle = {
+         log = 1,
+         grout = 1
+      }
+   },
 
    buildcost = {
       log = 3,
       blackwood = 2,
       granite = 1,
-      thatch_reed = 1
+      reed = 1
    },
    return_on_dismantle = {
       log = 1,
@@ -51,24 +63,22 @@ tribes:new_productionsite_type {
       { name = "meat", amount = 4 },
       { name = "barbarians_bread", amount = 4 }
    },
-   outputs = {
-      "ration"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start preparing a ration because ...
          descname = _"preparing a ration",
          actions = {
              -- time total: 33
             "return=skipped unless economy needs ration",
-            "sleep=5000",
             "consume=barbarians_bread,fish,meat",
-            "playsound=sound/barbarians/taverns tavern 100",
-            "animate=working 18000",
-            "sleep=10000",
+            "playsound=sound/barbarians/taverns/tavern priority:80%",
+            "animate=working duration:23s",
+            "sleep=duration:10s",
             "produce=ration"
          },
       },
    },
 }
+
+pop_textdomain()
