@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_productionsite_type {
    name = "barbarians_well",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Well"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -32,7 +32,6 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      collects_ware_from_map = "water",
       basic_amount = 1
    },
 
@@ -40,18 +39,14 @@ tribes:new_productionsite_type {
       barbarians_carrier = 1
    },
 
-   outputs = {
-      "water"
-   },
-
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
          descname = _"working",
          actions = {
-            "sleep=20000",
-            "animate=working 20000",
-            "mine=water 1 100 65 2",
+            "sleep=duration:20s",
+            "animate=working duration:20s",
+            "mine=resource_water radius:1 yield:100% when_empty:65%",
             "produce=water",
          }
       },
@@ -65,3 +60,5 @@ tribes:new_productionsite_type {
       productivity_threshold = 33
    },
 }
+
+pop_textdomain()
