@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "empire_building",
+descriptions:new_productionsite_type {
    name = "empire_brewery",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Brewery"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
 
@@ -44,22 +44,21 @@ tribes:new_productionsite_type {
       { name = "water", amount = 7 },
       { name = "wheat", amount = 7 }
    },
-   outputs = {
-      "beer"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start brewing beer because ...
          descname = _"brewing beer",
          actions = {
-            "sleep=30000",
             "return=skipped unless economy needs beer",
             "consume=water wheat",
-            "playsound=sound/empire beerbubble 180",
-            "animate=working 30000",
+            "sleep=duration:30s",
+            "playsound=sound/empire/beerbubble priority:40% allow_multiple",
+            "animate=working duration:30s",
             "produce=beer"
          }
       },
    },
 }
+
+pop_textdomain()
