@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "empire_building",
+descriptions:new_productionsite_type {
    name = "empire_foresters_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Forester’s House"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -28,7 +28,6 @@ tribes:new_productionsite_type {
 
    aihints = {
       space_consumer = true,
-      supports_production_of = { "log" },
       very_weak_ai_limit = 2,
       weak_ai_limit = 4
    },
@@ -38,13 +37,15 @@ tribes:new_productionsite_type {
    },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start planting trees because ...
          descname = _"planting trees",
          actions = {
-            "sleep=11000",
-            "callworker=plant"
+            "callworker=plant",
+            "sleep=duration:10s"
          }
       },
    },
 }
+
+pop_textdomain()
