@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "empire_building",
+descriptions:new_productionsite_type {
    name = "empire_mill",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Mill"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
 
@@ -43,22 +43,21 @@ tribes:new_productionsite_type {
    inputs = {
       { name = "wheat", amount = 6 }
    },
-   outputs = {
-      "flour"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start grinding wheat because ...
          descname = _"grinding wheat",
          actions = {
-            "sleep=5000",
             "return=skipped unless economy needs flour",
             "consume=wheat",
-            "playsound=sound/mill mill_turning 240",
-            "animate=working 10000",
+            "sleep=duration:5s",
+            "playsound=sound/mill/mill_turning priority:90% allow_multiple",
+            "animate=working duration:10s",
             "produce=flour"
          }
       },
    },
 }
+
+pop_textdomain()
