@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "empire_building",
+descriptions:new_productionsite_type {
    name = "empire_sheepfarm",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Sheep Farm"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "big",
 
@@ -44,22 +44,21 @@ tribes:new_productionsite_type {
       { name = "water", amount = 7 },
       { name = "wheat", amount = 7 }
    },
-   outputs = {
-      "wool"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start breeding sheep because ...
          descname = _"breeding sheep",
          actions = {
             "return=skipped unless economy needs wool",
             "consume=water wheat",
-            "sleep=25000",
-            "playsound=sound/farm/sheep 192",
-            "animate=working 30000",
+            "sleep=duration:25s",
+            "playsound=sound/farm/sheep priority:50% allow_multiple",
+            "animate=working duration:30s",
             "produce=wool"
          }
       },
    },
 }
+
+pop_textdomain()
