@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "frisians_building",
+descriptions:new_productionsite_type {
    name = "frisians_foresters_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("frisians_building", "Forester’s House"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -39,7 +39,6 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      supports_production_of = { "log" },
       space_consumer = true,
    },
 
@@ -47,23 +46,16 @@ tribes:new_productionsite_type {
       frisians_forester = 1
    },
 
-   indicate_workarea_overlaps = {
-      frisians_clay_pit = false,
-      frisians_berry_farm = false,
-      frisians_reed_farm = false,
-      frisians_farm = false,
-      frisians_foresters_house = false,
-      frisians_woodcutters_house = true,
-   },
-
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start planting trees because ...
          descname = _"planting trees",
          actions = {
             "callworker=plant",
-            "sleep=12000"
+            "sleep=duration:12s"
          }
       },
    },
 }
+
+pop_textdomain()
