@@ -1,15 +1,16 @@
+push_textdomain("tribes")
+
 dirname = path.dirname (__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "frisians_building",
+descriptions:new_productionsite_type {
    name = "frisians_scouts_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext ("frisians_building", "Scout’s House"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
    buildcost = {
+      brick = 1,
       granite = 1,
       log = 1,
       reed = 1
@@ -49,14 +50,23 @@ tribes:new_productionsite_type {
    },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start scouting because ...
          descname = _"scouting",
          actions = {
             "consume=ration",
-            "sleep=30000",
+            "sleep=duration:30s",
             "callworker=scout"
          }
       },
+      targeted_scouting = {
+         descname = _"scouting",
+         actions = {
+            "consume=ration",
+            "callworker=targeted_scouting"
+         }
+      },
    },
 }
+
+pop_textdomain()
