@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname (__file__)
 
-tribes:new_productionsite_type {
-   msgctxt = "frisians_building",
+descriptions:new_productionsite_type {
    name = "frisians_shipyard",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext ("frisians_building", "Shipyard"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "medium",
    map_check = {"seafaring"},
@@ -48,10 +48,6 @@ tribes:new_productionsite_type {
       prohibited_till = 1050
    },
 
-   indicate_workarea_overlaps = {
-      frisians_shipyard = false,
-   },
-
    working_positions = {
       frisians_shipwright = 1
    },
@@ -63,7 +59,7 @@ tribes:new_productionsite_type {
    },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
          descname = _"working",
          actions = {
@@ -75,16 +71,18 @@ tribes:new_productionsite_type {
          -- TRANSLATORS: Completed/Skipped/Did not start constructing a ship because ...
          descname = _"constructing a ship",
          actions = {
-            "construct=frisians_shipconstruction buildship 6",
-            "sleep=20000",
+            "construct=frisians_shipconstruction worker:buildship radius:6",
+            "sleep=duration:20s",
          }
       },
       ship_preparation = {
          descname = _"working",
          actions = {
-            "sleep=35000",
+            "sleep=duration:35s",
             -- no working animation yet
          }
       },
    },
 }
+
+pop_textdomain()
