@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_trainingsite_type {
-   msgctxt = "barbarians_building",
+descriptions:new_trainingsite_type {
    name = "barbarians_trainingcamp",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Training Camp"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "big",
 
@@ -62,13 +62,8 @@ tribes:new_trainingsite_type {
       { name = "helmet_mask", amount = 2 },
       { name = "helmet_warhelm", amount = 2 }
    },
-   outputs = {
-      "barbarians_soldier",
-   },
 
    ["soldier attack"] = {
-      min_level = 0,
-      max_level = 4,
       food = {
          {"fish", "meat"},
          {"barbarians_bread"}
@@ -82,8 +77,6 @@ tribes:new_trainingsite_type {
       }
    },
    ["soldier health"] = {
-      min_level = 0,
-      max_level = 2,
       food = {
          {"fish", "meat"},
          {"barbarians_bread"}
@@ -100,7 +93,7 @@ tribes:new_trainingsite_type {
          -- TRANSLATORS: Completed/Skipped/Did not start sleeping because ...
          descname = _"sleeping",
          actions = {
-            "sleep=5000",
+            "sleep=duration:5s",
             "return=skipped",
          }
       },
@@ -108,115 +101,124 @@ tribes:new_trainingsite_type {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier attack from level 0 to level 1"),
          actions = {
-            "checksoldier=soldier attack 0", -- Fails when aren't any soldier of level 0 attack
+            "checksoldier=soldier:attack level:0", -- Fails when aren't any soldier of level 0 attack
             "return=failed unless site has ax_sharp",
             "return=failed unless site has fish,meat",
             "return=failed unless site has barbarians_bread",
-            "sleep=30000",
-            "checksoldier=soldier attack 0", -- Because the soldier can be expelled by the player
+            "sleep=duration:30s",
+            "checksoldier=soldier:attack level:0", -- Because the soldier can be expelled by the player
             "consume=ax_sharp fish,meat barbarians_bread",
-            "train=soldier attack 0 1"
+            "train=soldier:attack level:1"
          }
       },
       upgrade_soldier_attack_1 = {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier attack from level 1 to level 2"),
          actions = {
-            "checksoldier=soldier attack 1",
+            "checksoldier=soldier:attack level:1",
             "return=failed unless site has ax_broad",
             "return=failed unless site has fish,meat",
             "return=failed unless site has barbarians_bread",
-            "sleep=30000",
-            "checksoldier=soldier attack 1",
+            "sleep=duration:30s",
+            "checksoldier=soldier:attack level:1",
             "consume=ax_broad fish,meat barbarians_bread",
-            "train=soldier attack 1 2"
+            "train=soldier:attack level:2"
          }
       },
       upgrade_soldier_attack_2 = {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier attack from level 2 to level 3"),
          actions = {
-            "checksoldier=soldier attack 2",
+            "checksoldier=soldier:attack level:2",
             "return=failed unless site has ax_bronze",
             "return=failed unless site has fish,meat",
             "return=failed unless site has barbarians_bread",
-            "sleep=30000",
-            "checksoldier=soldier attack 2",
+            "sleep=duration:30s",
+            "checksoldier=soldier:attack level:2",
             "consume=ax_bronze fish,meat barbarians_bread",
-            "train=soldier attack 2 3"
+            "train=soldier:attack level:3"
          }
       },
       upgrade_soldier_attack_3 = {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier attack from level 3 to level 4"),
          actions = {
-            "checksoldier=soldier attack 3",
+            "checksoldier=soldier:attack level:3",
             "return=failed unless site has ax_battle",
             "return=failed unless site has fish,meat:2",
             "return=failed unless site has barbarians_bread",
-            "sleep=30000",
-            "checksoldier=soldier attack 3",
+            "sleep=duration:30s",
+            "checksoldier=soldier:attack level:3",
             "consume=ax_battle fish,meat:2 barbarians_bread",
-            "train=soldier attack 3 4"
+            "train=soldier:attack level:4"
          }
       },
       upgrade_soldier_attack_4 = {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier attack from level 4 to level 5"),
          actions = {
-            "checksoldier=soldier attack 4",
+            "checksoldier=soldier:attack level:4",
             "return=failed unless site has ax_warriors",
             "return=failed unless site has fish,meat",
             "return=failed unless site has barbarians_bread:2",
-            "sleep=30000",
-            "checksoldier=soldier attack 4",
+            "sleep=duration:30s",
+            "checksoldier=soldier:attack level:4",
             "consume=ax_warriors fish,meat barbarians_bread:2",
-            "train=soldier attack 4 5"
+            "train=soldier:attack level:5"
          }
       },
       upgrade_soldier_health_0 = {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier health from level 0 to level 1"),
          actions = {
-            "checksoldier=soldier health 0",
+            "checksoldier=soldier:health level:0",
             "return=failed unless site has helmet",
             "return=failed unless site has barbarians_bread,fish,meat",
-            "sleep=30000",
-            "checksoldier=soldier health 0",
+            "sleep=duration:30s",
+            "checksoldier=soldier:health level:0",
             "consume=helmet barbarians_bread,fish,meat",
-            "train=soldier health 0 1"
+            "train=soldier:health level:1"
          }
       },
       upgrade_soldier_health_1 = {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier health from level 1 to level 2"),
          actions = {
-            "checksoldier=soldier health 1",
+            "checksoldier=soldier:health level:1",
             "return=failed unless site has helmet_mask",
             "return=failed unless site has fish,meat",
             "return=failed unless site has barbarians_bread",
-            "sleep=30000",
-            "checksoldier=soldier health 1",
+            "sleep=duration:30s",
+            "checksoldier=soldier:health level:1",
             "consume=helmet_mask fish,meat barbarians_bread",
-            "train=soldier health 1 2"
+            "train=soldier:health level:2"
          }
       },
       upgrade_soldier_health_2 = {
          -- TRANSLATORS: Completed/Skipped/Did not start upgrading ... because ...
          descname = pgettext("barbarians_building", "upgrading soldier health from level 2 to level 3"),
          actions = {
-            "checksoldier=soldier health 2",
+            "checksoldier=soldier:health level:2",
             "return=failed unless site has helmet_warhelm",
             "return=failed unless site has fish,meat:2",
             "return=failed unless site has barbarians_bread",
-            "sleep=30000",
-            "checksoldier=soldier health 2",
+            "sleep=duration:30s",
+            "checksoldier=soldier:health level:2",
             "consume=helmet_warhelm fish,meat:2 barbarians_bread",
-            "train=soldier health 2 3"
+            "train=soldier:health level:3"
          }
       },
    },
 
    soldier_capacity = 12,
-   trainer_patience = 5
+   trainer_patience = 10,
+
+   messages = {
+      -- TRANSLATORS: Barbarian training site tooltip when it has no soldiers assigned
+      no_soldier = pgettext("barbarians_building", "No soldier to train!"),
+      -- TRANSLATORS: Barbarian training site tooltip when none of the present soldiers match the current training program
+      no_soldier_for_level = pgettext("barbarians_building", "No soldier found for this training level!"),
+   },
 }
+
+pop_textdomain()
