@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_warehouse_type {
-   msgctxt = "barbarians_building",
+descriptions:new_warehouse_type {
    name = "barbarians_headquarters",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Headquarters"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "big",
    destructible = false,
@@ -26,3 +26,5 @@ tribes:new_warehouse_type {
    heal_per_second = 220,
    conquers = 9,
 }
+
+pop_textdomain()
