@@ -1,18 +1,17 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_immovable_type {
-   msgctxt = "immovable",
+descriptions:new_immovable_type {
    name = "atlanteans_shipconstruction",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Ship Under Construction"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
-   attributes = { "shipconstruction" },
    programs = {
-      program = {
-         "construct=idle 5000 210000",
-         "transform=bob atlanteans_ship",
+      main = {
+         "construct=idle duration:5s decay_after:3m30s",
+         "transform=bob:atlanteans_ship",
       }
    },
    buildcost = {
@@ -30,3 +29,5 @@ tribes:new_immovable_type {
       },
    }
 }
+
+pop_textdomain()
