@@ -1,15 +1,17 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_immovable_type {
-   msgctxt = "immovable",
+descriptions:new_immovable_type {
    name = "empire_shipconstruction",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Ship Under Construction"),
+   icon = dirname .. "menu.png",
    size = "small",
    programs = {
-      program = {
-         "construction=idle 5000 210000",
-         "transform=bob tribe:empire_ship",
+      main = {
+         "construct=idle duration:5s decay_after:3m30s",
+         "transform=bob:empire_ship",
       }
    },
    buildcost = {
@@ -22,7 +24,10 @@ tribes:new_immovable_type {
       idle = {
          pictures = path.list_files(dirname .. "build_??.png"),
          hotspot = { 115, 78 },
-         fps = 1
+         fps = 1,
+         representative_frame = 5
       },
    }
 }
+
+pop_textdomain()
