@@ -1,17 +1,16 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_immovable_type {
-   msgctxt = "immovable",
+descriptions:new_immovable_type {
    name = "wheatfield_tiny",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Wheat Field (tiny)"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
-   attributes = { "field", "seed_wheat" },
    programs = {
-      program = {
-         "animate=idle 30000",
+      main = {
+         "animate=idle duration:30s",
          "transform=wheatfield_small",
       }
    },
@@ -23,3 +22,5 @@ tribes:new_immovable_type {
       },
    }
 }
+
+pop_textdomain()
