@@ -1,18 +1,12 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_ware_type {
-   msgctxt = "empire_ware",
+descriptions:new_ware_type {
    name = "empire_bread",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("empire_ware", "Bread"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
-   default_target_quantity = {
-      empire = 20
-   },
-   preciousness = {
-      empire = 7
-   },
 
    animations = {
       idle = {
@@ -21,3 +15,5 @@ tribes:new_ware_type {
       },
    }
 }
+
+pop_textdomain()
