@@ -1,16 +1,12 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_ware_type {
-   msgctxt = "ware",
+descriptions:new_ware_type {
    name = "corn",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Corn"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
-   default_target_quantity = {},
-   preciousness = {
-      atlanteans = 12
-   },
 
    animations = {
       idle = {
@@ -19,3 +15,5 @@ tribes:new_ware_type {
       },
    }
 }
+
+pop_textdomain()
