@@ -1,21 +1,12 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_ware_type {
-   msgctxt = "ware",
+descriptions:new_ware_type {
    name = "fish",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Fish"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
-   default_target_quantity = {
-      frisians = 20,
-   },
-   preciousness = {
-      atlanteans = 4,
-      barbarians = 3,
-      frisians = 1,
-      empire = 3,
-   },
 
    animations = {
       idle = {
@@ -24,3 +15,5 @@ tribes:new_ware_type {
       },
    }
 }
+
+pop_textdomain()
