@@ -1,18 +1,12 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_ware_type {
-   msgctxt = "ware",
+descriptions:new_ware_type {
    name = "gold_thread",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Gold Thread"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
-   default_target_quantity = {
-      atlanteans = 5
-   },
-   preciousness = {
-      atlanteans = 2
-   },
 
    animations = {
       idle = {
@@ -21,3 +15,5 @@ tribes:new_ware_type {
       },
    }
 }
+
+pop_textdomain()
