@@ -1,23 +1,19 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_ware_type {
-   msgctxt = "frisians_ware",
+descriptions:new_ware_type {
    name = "helmet_golden",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("frisians_ware", "Golden Helmet"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
-   default_target_quantity = {
-      frisians = 2
-   },
-   preciousness = {
-      frisians = 3
-   },
 
    animations = {
       idle = {
          pictures = path.list_files(dirname .. "idle.png"),
-         hotspot = { 7, 8 },
+         hotspot = {8, 6},
       },
    }
 }
+
+pop_textdomain()
