@@ -1,22 +1,12 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_ware_type {
-   msgctxt = "ware",
+descriptions:new_ware_type {
    name = "hunting_spear",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Hunting Spear"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
-   default_target_quantity = {
-      barbarians = 1,
-      frisians = 1,
-      empire = 1
-   },
-   preciousness = {
-      barbarians = 0,
-      frisians = 0,
-      empire = 0
-   },
 
    animations = {
       idle = {
@@ -25,3 +15,5 @@ tribes:new_ware_type {
       },
    }
 }
+
+pop_textdomain()
