@@ -1,20 +1,12 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_ware_type {
-   msgctxt = "ware",
+descriptions:new_ware_type {
    name = "smoked_meat",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Smoked Meat"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
-   default_target_quantity = {
-      atlanteans = 20,
-      frisians = 10
-   },
-   preciousness = {
-      atlanteans = 2,
-      frisians = 7
-   },
 
    animations = {
       idle = {
@@ -23,3 +15,5 @@ tribes:new_ware_type {
       },
    }
 }
+
+pop_textdomain()
