@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_worker_type {
-   msgctxt = "barbarians_worker",
+descriptions:new_worker_type {
    name = "barbarians_miner_master",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("barbarians_worker", "Master Miner"),
-   helptext_script = dirname .. "helptexts.lua",
    animation_directory = dirname,
    icon = dirname .. "menu.png",
    vision_range = 2,
@@ -34,3 +34,5 @@ tribes:new_worker_type {
       }
    }
 }
+
+pop_textdomain()
