@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-tribes:new_worker_type {
-   msgctxt = "barbarians_worker",
+descriptions:new_worker_type {
    name = "barbarians_scout",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("barbarians_worker", "Scout"),
-   helptext_script = dirname .. "helptexts.lua",
    animation_directory = dirname,
    icon = dirname .. "menu.png",
    vision_range = 3,
@@ -16,7 +16,12 @@ tribes:new_worker_type {
 
    programs = {
       scout = {
-         "scout=15 75000", -- radius 15, 75 seconds until return
+         "scout=radius:15 duration:1m15s",
+         "return"
+      },
+      targeted_scouting = {
+         "walk=object",
+         "scout=radius:15 duration:1m15s",
          "return"
       }
    },
@@ -37,3 +42,5 @@ tribes:new_worker_type {
       }
    }
 }
+
+pop_textdomain()
