@@ -1,22 +1,12 @@
+push_textdomain("tribes")
+
 dirname = path.dirname(__file__)
 
-animations = {
-   idle = {
-      pictures = path.list_files(dirname .. "idle_??.png"),
-      hotspot = { 10, 21 },
-      fps = 10
-   }
-}
-add_directional_animation(animations, "walk", dirname, "walk", {9, 32}, 10)
-add_directional_animation(animations, "walkload", dirname, "walkload", {9, 32}, 10)
-
-
-tribes:new_worker_type {
-   msgctxt = "empire_worker",
+descriptions:new_worker_type {
    name = "empire_hunter",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("empire_worker", "Hunter"),
-   helptext_script = dirname .. "helptexts.lua",
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    vision_range = 2,
 
@@ -28,12 +18,29 @@ tribes:new_worker_type {
       hunt = {
          "findobject=type:bob radius:13 attrib:eatable",
          "walk=object",
-         "animate=idle 1000",
+         "animate=idle duration:1s",
          "removeobject",
          "createware=meat",
          "return"
       }
    },
 
-   animations = animations,
+   animations = {
+      idle = {
+         hotspot = { 10, 21 },
+         fps = 10
+      },
+      walk = {
+         hotspot = { 9, 32 },
+         fps = 10,
+         directional = true
+      },
+      walkload = {
+         hotspot = { 9, 32 },
+         fps = 10,
+         directional = true
+      }
+   }
 }
+
+pop_textdomain()
