@@ -1,11 +1,11 @@
+push_textdomain("tribes")
+
 dirname = path.dirname (__file__)
 
-tribes:new_worker_type {
-   msgctxt = "frisians_worker",
+descriptions:new_worker_type {
    name = "frisians_baker_master",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext ("frisians_worker", "Master Baker"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    vision_range = 2,
 
@@ -41,3 +41,5 @@ tribes:new_worker_type {
       },
    },
 }
+
+pop_textdomain()
