@@ -1,11 +1,11 @@
+push_textdomain("world")
+
 dirname = path.dirname(__file__)
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "standing_stone2_winter",
    descname = _ "Standing Stone",
-   editor_category = "standing_stones",
    size = "big",
-   attributes = {},
    programs = {},
    animations = {
       idle = {
@@ -14,3 +14,5 @@ world:new_immovable_type{
       },
    }
 }
+
+pop_textdomain()
