@@ -1,3 +1,5 @@
+push_textdomain("world")
+
 dirname = path.dirname(__file__)
 
 terrain_affinity = {
@@ -7,17 +9,15 @@ terrain_affinity = {
    pickiness = 60,
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "beech_summer_sapling",
    descname = _ "Beech (Sapling)",
-   editor_category = "trees_deciduous",
    size = "small",
-   attributes = { "tree_sapling" },
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 55000",
-         "remove=35",
+      main = {
+         "animate=idle duration:55s",
+         "remove=chance:13.67%",
          "grow=beech_summer_pole",
       },
    },
@@ -29,22 +29,21 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 6, 13 }
+         hotspot = { 5, 12 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "beech_summer_pole",
    descname = _ "Beech (Pole)",
-   editor_category = "trees_deciduous",
    size = "small",
-   attributes = {},
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 65000",
-         "remove=24",
+      main = {
+         "animate=idle duration:1m5s",
+         "remove=chance:9.37%",
          "grow=beech_summer_mature",
       },
    },
@@ -56,22 +55,20 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 13, 29 }
+         hotspot = { 12, 28 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "beech_summer_mature",
    descname = _ "Beech (Mature)",
-   editor_category = "trees_deciduous",
    size = "small",
-   attributes = {},
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 72000",
-         "remove=19",
+      main = {
+         "animate=idle duration:1m12s",
+         "remove=chance:7.42%",
          "grow=beech_summer_old",
       },
    },
@@ -83,25 +80,24 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 19, 49 }
+         hotspot = { 18, 48 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "beech_summer_old",
    descname = _ "Beech (Old)",
    species = _ "Beech",
    icon = dirname .. "menu.png",
-   editor_category = "trees_deciduous",
    size = "small",
-   attributes = { "tree" },
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 1525000",
-         "transform=deadtree2 20",
-         "seed=beech_summer_sapling 250",
+      main = {
+         "animate=idle duration:25m25s",
+         "transform=deadtree2 chance:7.81%",
+         "seed=beech_summer_sapling proximity:97.66%",
       },
       fall = {
          "remove=",
@@ -115,10 +111,13 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 25, 61 },
+         hotspot = { 24, 60 },
          sound_effect = {
             path = "sound/animals/bird6",
+            priority = "10%"
          },
       }
    },
 }
+
+pop_textdomain()
