@@ -1,3 +1,5 @@
+push_textdomain("world")
+
 dirname = path.dirname(__file__)
 
 terrain_affinity = {
@@ -7,17 +9,15 @@ terrain_affinity = {
    pickiness = 60,
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_borassus_desert_sapling",
    descname = _ "Borassus Palm (Sapling)",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = { "tree_sapling" },
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 70000",
-         "remove=80",
+      main = {
+         "animate=idle duration:1m10s",
+         "remove=chance:31.25%",
          "grow=palm_borassus_desert_pole",
       },
    },
@@ -29,22 +29,21 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 6, 13 }
+         hotspot = { 5, 12 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_borassus_desert_pole",
    descname = _ "Borassus Palm (Pole)",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = {},
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 70000",
-         "remove=70",
+      main = {
+         "animate=idle duration:1m10s",
+         "remove=chance:27.34%",
          "grow=palm_borassus_desert_mature",
       },
    },
@@ -56,22 +55,20 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 13, 29 }
+         hotspot = { 12, 28 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_borassus_desert_mature",
    descname = _ "Borassus Palm (Mature)",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = {},
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 65000",
-         "remove=40",
+      main = {
+         "animate=idle duration:1m5s",
+         "remove=chance:15.62%",
          "grow=palm_borassus_desert_old",
       },
    },
@@ -83,25 +80,24 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 19, 49 }
+         hotspot = { 18, 48 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_borassus_desert_old",
    descname = _ "Borassus Palm (Old)",
    species = _ "Borassus Palm",
    icon = dirname .. "menu.png",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = { "tree" },
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 2000000",
-         "transform=deadtree5 25",
-         "seed=palm_borassus_desert_sapling 160",
+      main = {
+         "animate=idle duration:33m20s",
+         "transform=deadtree5 chance:9.76%",
+         "seed=palm_borassus_desert_sapling proximity:62.5%",
       },
       fall = {
          "remove=",
@@ -115,10 +111,13 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 25, 61 },
+         hotspot = { 24, 60 },
          sound_effect = {
             path = "sound/animals/crickets1",
+            priority = "10%"
          },
       }
    },
 }
+
+pop_textdomain()
