@@ -1,3 +1,5 @@
+push_textdomain("world")
+
 dirname = path.dirname(__file__)
 
 terrain_affinity = {
@@ -7,17 +9,15 @@ terrain_affinity = {
    pickiness = 90,
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_roystonea_desert_sapling",
    descname = _ "Roystonea regia Palm (Sapling)",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = { "tree_sapling" },
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 57500",
-         "remove=21",
+      main = {
+         "animate=idle duration:57s500ms",
+         "remove=chance:8.20%",
          "grow=palm_roystonea_desert_pole",
       },
    },
@@ -29,22 +29,21 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 6, 13 }
+         hotspot = { 5, 12 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_roystonea_desert_pole",
    descname = _ "Roystonea regia Palm (Pole)",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = {},
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 52500",
-         "remove=19",
+      main = {
+         "animate=idle duration:52s500ms",
+         "remove=chance:7.42%",
          "grow=palm_roystonea_desert_mature",
       },
    },
@@ -56,22 +55,20 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 13, 29 }
+         hotspot = { 12, 28 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_roystonea_desert_mature",
    descname = _ "Roystonea regia Palm (Mature)",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = {},
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 50000",
-         "remove=18",
+      main = {
+         "animate=idle duration:50s",
+         "remove=chance:7.03%",
          "grow=palm_roystonea_desert_old",
       },
    },
@@ -83,25 +80,24 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 19, 49 }
+         hotspot = { 18, 48 }
       }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "palm_roystonea_desert_old",
    descname = _ "Roystonea regia Palm (Old)",
    species = _ "Roystonea regia Palm",
    icon = dirname .. "menu.png",
-   editor_category = "trees_palm",
    size = "small",
-   attributes = { "tree" },
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 1550000",
-         "transform=deadtree4 39",
-         "seed=palm_roystonea_desert_sapling 30",
+      main = {
+         "animate=idle duration:25m50s",
+         "transform=deadtree4 chance:15.23%",
+         "seed=palm_roystonea_desert_sapling proximity:11.72%",
       },
       fall = {
          "remove=",
@@ -115,10 +111,13 @@ world:new_immovable_type{
          frames = 4,
          rows = 2,
          columns = 2,
-         hotspot = { 25, 61 },
+         hotspot = { 24, 60 },
          sound_effect = {
             path = "sound/animals/crickets2",
+            priority = "10%"
          },
       }
    },
 }
+
+pop_textdomain()
