@@ -1,3 +1,5 @@
+push_textdomain("world")
+
 dirname = path.dirname(__file__)
 
 terrain_affinity = {
@@ -7,103 +9,116 @@ terrain_affinity = {
    pickiness = 80,
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "umbrella_green_wasteland_sapling",
    -- TRANSLATORS: This is a fictitious tree. Be creative if you want.
    descname = _ "Green Umbrella Tree (Sapling)",
-   editor_category = "trees_wasteland",
    size = "small",
-   attributes = { "tree_sapling" },
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 57000",
-         "remove=21",
+      main = {
+         "animate=idle duration:57s",
+         "remove=chance:8.20%",
          "grow=umbrella_green_wasteland_pole",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "sapling/idle_?.png"),
-         hotspot = { 5, 12 },
+         directory = dirname,
+         basename = "sapling",
          fps = 8,
-      },
+         frames = 5,
+         rows = 3,
+         columns = 2,
+         hotspot = { 5, 12 }
+      }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "umbrella_green_wasteland_pole",
    -- TRANSLATORS: This is a fictitious tree. Be creative if you want.
    descname = _ "Green Umbrella Tree (Pole)",
-   editor_category = "trees_wasteland",
    size = "small",
-   attributes = {},
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 53000",
-         "remove=19",
+      main = {
+         "animate=idle duration:53s",
+         "remove=chance:7.42%",
          "grow=umbrella_green_wasteland_mature",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "pole/idle_?.png"),
-         hotspot = { 12, 28 },
+         directory = dirname,
+         basename = "pole",
          fps = 8,
-      },
+         frames = 5,
+         rows = 3,
+         columns = 2,
+         hotspot = { 12, 28 }
+      }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "umbrella_green_wasteland_mature",
    -- TRANSLATORS: This is a fictitious tree. Be creative if you want.
    descname = _ "Green Umbrella Tree (Mature)",
-   editor_category = "trees_wasteland",
    size = "small",
-   attributes = {},
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 50000",
-         "remove=18",
+      main = {
+         "animate=idle duration:50s",
+         "remove=chance:7.03%",
          "grow=umbrella_green_wasteland_old",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "mature/idle_?.png"),
-         hotspot = { 18, 48 },
+         directory = dirname,
+         basename = "mature",
          fps = 8,
-      },
+         frames = 5,
+         rows = 3,
+         columns = 2,
+         hotspot = { 18, 48 }
+      }
    },
 }
 
-world:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "umbrella_green_wasteland_old",
    -- TRANSLATORS: This is a fictitious tree. Be creative if you want.
    descname = _ "Green Umbrella Tree (Old)",
    -- TRANSLATORS: This is a fictitious tree. Be creative if you want.
    species = _ "Green Umbrella Tree",
-   editor_category = "trees_wasteland",
+   icon = dirname .. "menu.png",
    size = "small",
-   attributes = { "tree" },
+
    terrain_affinity = terrain_affinity,
    programs = {
-      program = {
-         "animate=idle 1550000",
-         "transform=deadtree4 39",
-         "seed=umbrella_green_wasteland_sapling",
+      main = {
+         "animate=idle duration:25m50s",
+         "transform=deadtree4 chance:15.23%",
+         "seed=umbrella_green_wasteland_sapling proximity:39%",
       },
       fall = {
          "remove=",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "old/idle_?.png"),
-         hotspot = { 24, 60 },
+         directory = dirname,
+         basename = "old",
          fps = 10,
-      },
+         frames = 5,
+         rows = 3,
+         columns = 2,
+         hotspot = { 24, 60 }
+      }
    },
 }
+
+pop_textdomain()
