@@ -15,12 +15,6 @@
 -- Which resource can be placed where on the map is defined in each terrain's
 -- ``valid_resources`` table.
 --
--- The resource names are currently hard-coded in the ``geologist`` worker program
--- (`bug #1713706 <https://bugs.launchpad.net/widelands/+bug/1713706>`_), so we can't add any detectable resources at the moment.
-
-pics_dir = path.dirname(__file__) .. "pics/"
-
--- RST
 -- .. function:: new_resource_type{table}
 --
 --    This function adds the definition of a resource to the engine.
@@ -79,8 +73,40 @@ pics_dir = path.dirname(__file__) .. "pics/"
 --               [1000] = pics_dir .. "coal4.png", -- Use this image for amount > 15;
 --            }
 --
-world:new_resource_type{
-   name = "coal",
+-- For making the UI texts translateable, we also need to push/pop the correct textdomain.
+--
+-- Example:
+--
+-- .. code-block:: lua
+--
+--    push_textdomain("world")
+--
+--    pics_dir = path.dirname(__file__) .. "pics/"
+--
+--    wl.Descriptions():new_resource_type{
+--       name = "resource_coal",
+--       descname = _ "Coal",
+--       max_amount = 20,
+--       detectable = true,
+--       timeout_ms = 300000,
+--       timeout_radius = 8,
+--       representative_image = pics_dir .. "coal4.png",
+--       editor_pictures = {
+--          [5] = pics_dir .. "coal1.png",
+--          [10] = pics_dir .. "coal2.png",
+--          [15] = pics_dir .. "coal3.png",
+--          [1000] = pics_dir .. "coal4.png",
+--       }
+--    }
+--
+--    pop_textdomain()
+
+push_textdomain("world")
+
+pics_dir = path.dirname(__file__) .. "pics/"
+
+wl.Descriptions():new_resource_type{
+   name = "resource_coal",
    descname = _ "Coal",
    max_amount = 20,
    detectable = true,
@@ -95,8 +121,8 @@ world:new_resource_type{
    }
 }
 
-world:new_resource_type{
-   name = "gold",
+wl.Descriptions():new_resource_type{
+   name = "resource_gold",
    descname = _ "Gold",
    max_amount = 20,
    detectable = true,
@@ -111,8 +137,8 @@ world:new_resource_type{
    }
 }
 
-world:new_resource_type{
-   name = "iron",
+wl.Descriptions():new_resource_type{
+   name = "resource_iron",
    descname = _ "Iron",
    max_amount = 20,
    detectable = true,
@@ -127,8 +153,8 @@ world:new_resource_type{
    }
 }
 
-world:new_resource_type{
-   name = "stones",
+wl.Descriptions():new_resource_type{
+   name = "resource_stones",
    descname = _ "Stones",
    max_amount = 20,
    detectable = true,
@@ -143,8 +169,8 @@ world:new_resource_type{
    }
 }
 
-world:new_resource_type{
-   name = "water",
+wl.Descriptions():new_resource_type{
+   name = "resource_water",
    descname = _ "Water",
    max_amount = 50,
    detectable = true,
@@ -159,8 +185,8 @@ world:new_resource_type{
    }
 }
 
-world:new_resource_type{
-   name = "fish",
+wl.Descriptions():new_resource_type{
+   name = "resource_fish",
    descname = _ "Fish",
    max_amount = 20,
    detectable = false,
@@ -174,3 +200,5 @@ world:new_resource_type{
       [1000] = pics_dir .. "fish4.png",
    }
 }
+
+pop_textdomain()
